@@ -2,8 +2,8 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006-2008 Vlad Vasiliev
- * Copyright (C) 2006-2008 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * 	for the code
  *        
  * Copyright (C) 2008 Andrew Zhilin
@@ -36,7 +36,8 @@ gboolean not_event = FALSE;
 /*******************************************************************************/
 static GSList *event_time_list = NULL;
 /*******************************************************************************/
-gboolean timer_handler(gpointer data) {
+gboolean 
+timer_handler(gpointer data) {
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
     time_t current_time;
@@ -110,28 +111,13 @@ gboolean timer_handler(gpointer data) {
                 fprintf(stderr, "UPDATE by event\n");
 #endif
 
-#ifdef OS2008
-
-/* This is code for debug GPS
-
-                    double r;
-                    r = (   (double)rand() / ((double)(RAND_MAX)+(double)(1)) );
-                    app->temporary_station_latitude = r*90;
-                    r = (   (double)rand() / ((double)(RAND_MAX)+(double)(1)) );
-                    app->temporary_station_longtitude = r*200;
-                    r = (   (double)rand() / ((double)(RAND_MAX)+(double)(1)) );
-                    if (r<0.5)
-                        app->temporary_station_latitude = app->temporary_station_latitude  * -1;
-                    r = (   (double)rand() / ((double)(RAND_MAX)+(double)(1)) );
-                    if (r<0.5)
-                        app->temporary_station_longtitude = app->temporary_station_longtitude  * -1;
-                
-                    fprintf(file_log,"Event:  Calculate CHECK_GPS_POSITION %f %f %f %f %f\n",
+/* This is code for debug GPS 
+                    fprintf(stderr,"Event:  Calculate CHECK_GPS_POSITION %f %f %f %f %f\n",
                                     app->gps_station.latitude,app->gps_station.longtitude,
                                     app->temporary_station_latitude,app->temporary_station_longtitude,
                                     calculate_distance(app->gps_station.latitude,app->gps_station.longtitude,
                                                     app->temporary_station_latitude,app->temporary_station_longtitude));
-		    fflush(file_log);
+
 */
                 if (calculate_distance
                     (app->gps_station.latitude,
@@ -151,13 +137,23 @@ gboolean timer_handler(gpointer data) {
                         app->gps_station.longtitude =
                             app->temporary_station_longtitude;
                         delete_all_gps_stations();
+                        if (app->config->current_source)
+                                g_free(app->config->current_source);
+                            app->config->current_source =
+                                g_strdup("weather.com");
                         add_station_to_user_list(app->gps_station.name,
                                                  app->gps_station.id0,
-                                                 TRUE);
+                                                 TRUE, app->config->current_source);
                         if (!app->config->current_station_name
                             && !app->config->current_station_id) {
+                            /* Fix me if source are not weather.com */
+                            if (app->config->current_station_name)
+                                g_free(app->config->current_station_name);
                             app->config->current_station_name =
                                 g_strdup(app->gps_station.name);
+
+                            if (app->config->current_station_id)
+                                g_free(app->config->current_station_id);
                             app->config->current_station_id =
                                 g_strdup(app->gps_station.id0);
                         }
@@ -166,14 +162,13 @@ gboolean timer_handler(gpointer data) {
                         redraw_home_window(FALSE);
                     }
                 }
-#endif
-#ifdef OS2008
+#ifdef ENABLE_GPS
                 /* add periodic gps check */
                 if (app->gps_station.latitude == 0
                     && app->gps_station.longtitude == 0)
                     add_gps_event(1);
                 else
-                    add_gps_event(5);
+                    add_gps_event(1);
 #endif
                 break;
 #endif
@@ -198,6 +193,9 @@ gboolean timer_handler(gpointer data) {
         }
         list_time_event_temp = g_slist_next(list_time_event_temp);
     }
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
     return TRUE;
 }
 
