@@ -415,19 +415,19 @@ popup_switch_cb(GtkNotebook * nb, gpointer nb_page, gint page, gpointer data) {
 gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
                               gpointer user_data){
     GtkWidget	*notebook = NULL,
-		*tab = NULL,
-		*hour_tab = NULL,
-		*current_tab = NULL,
-		*label = NULL,
-		*vbox = NULL,
-		*buttons_box = NULL,
-		*label_box = NULL,
-		*copyright_box = NULL,
-		*no_weather_box = NULL;
+		        *tab = NULL,
+		        *hour_tab = NULL,
+		        *current_tab = NULL,
+		        *label = NULL,
+		        *vbox = NULL,
+		        *buttons_box = NULL,
+		        *label_box = NULL,
+		        *copyright_box = NULL,
+		        *no_weather_box = NULL;
     gint	active_tab = 0,
-		k = 0,
-		page = 0,
-		i = 1;
+		    k = 0,
+		    page = 0,
+		    i = 1;
     gchar	*day_name = NULL;
     time_t	current_time = 0,
 		diff_time,
@@ -529,7 +529,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
             gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
                                         current_tab,
                                         gtk_label_new(_("Now")));
-#if defined CLUTTER
+#ifndef CLUTTER
             g_idle_add((GSourceFunc)make_current_tab,current_tab);
 #endif
             add_item2object(&(app->tab_of_window_popup), (void*)current_tab);
@@ -743,13 +743,13 @@ GtkWidget* create_day_tab(GSList *current, GSList *day, gchar **day_name){
 		*day_text = NULL,
 		*night_text = NULL;
     gchar	buffer[1024],
-		symbol = 'C';
+		    symbol = 'C';
     struct tm	tmp_time_date_struct = {0};
     GdkPixbuf	*icon = NULL;
     gint	hi_temp,
-		low_temp,
-		day_invalid_count = 0,
-		night_invalid_count = 0;
+		    low_temp,
+		    day_invalid_count = 0,
+		    night_invalid_count = 0;
     const gchar	*wind_units_str[] = { "m/s", "km/h", "mi/h" };
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -789,78 +789,87 @@ GtkWidget* create_day_tab(GSList *current, GSList *day, gchar **day_name){
     set_font(title, NULL, font_size + 2); 
     /* create 24 hours data widget */
     day_night_hbox = gtk_hbox_new(FALSE, 10);
-    /* day data */
-    day_vbox = gtk_vbox_new(FALSE, 0);
-    /* hbox for day label and temperature */
-    day_label_temperature_hbox = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(day_vbox),
-			day_label_temperature_hbox,
-			TRUE, TRUE, 0);
-    /* prepare day label */
-    day_label = gtk_label_new(_("Day:"));
-    gtk_box_pack_start(GTK_BOX(day_label_temperature_hbox),
-			day_label, FALSE, TRUE, 0);
-    /* day temperature */
-    memset(buffer, 0, sizeof(buffer));
-    if(hi_temp == INT_MAX)
-	strncat(buffer, (char*)hash_table_find("N/A", FALSE),
-			( (strlen((char*)hash_table_find("N/A", FALSE)) > sizeof(buffer)) ?
-		        (sizeof(buffer) - 1) :
-		        (strlen((char*)hash_table_find("N/A", FALSE))) ) );
-    else
-	snprintf(buffer, sizeof(hi_temp) + 
-			( (strlen(("\302\260%c")) > sizeof(buffer)) ?
-		        (sizeof(buffer) - 1) : (strlen("\302\260%c")) ),
-			"%d\302\260%c", hi_temp, symbol);
-    gtk_box_pack_start(GTK_BOX(day_label_temperature_hbox),
-			gtk_label_new(buffer), FALSE, TRUE, 40);
-    /* hbox for icon and text */
-    day_icon_text_hbox = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(day_vbox),
-                        day_icon_text_hbox, TRUE, TRUE, 0);
-    /* day icon */
-    memset(buffer, 0, sizeof(buffer));
-    sprintf(buffer, "%s%s.png", app->config->icons_set_base, item_value(day, "day_icon"));
-    icon = gdk_pixbuf_new_from_file_at_size(buffer,
-                        BIG_ICON_SIZE,
-                        BIG_ICON_SIZE, NULL);
-    day_icon = create_icon_widget(icon, buffer, BIG_ICON_SIZE, &app->clutter_objects_in_popup_form);
-    gtk_box_pack_start(GTK_BOX(day_icon_text_hbox),
-                        day_icon, TRUE, TRUE, 5);
-/* prepare day text */
-    gtk_box_pack_start(GTK_BOX(day_icon_text_hbox),
-			day_text_vbox = gtk_vbox_new(FALSE, 0),
-			TRUE, TRUE, 0);
-    memset(buffer, 0, sizeof(buffer));
+    /* add day  items to main widget */
+    /* check for N/A fields in day */
     if(!strcmp((char*)item_value(day, "day_title"), "N/A"))
-	day_invalid_count++;
-    strcat(buffer, (char*)hash_table_find(item_value(day, "day_title"), FALSE));
-    strcat(buffer, _("\nPrecipitation: "));
-    snprintf(buffer + strlen(buffer), sizeof(buffer) - 1, "%s%%",
-		(char*)hash_table_find(item_value(day, "day_ppcp"), FALSE));
-    strcat(buffer, _("\nHumidity: "));
-    if(strcmp(item_value(day, "day_humidity"), "N/A"))
-	sprintf(buffer + strlen(buffer), "%s%%\n",
-		item_value(day, "day_humidity"));
-    else{
-	sprintf(buffer + strlen(buffer), "%s\n",
-			(char*)hash_table_find("N/A", FALSE));
-	day_invalid_count++;
-    }
-    strcat(buffer, _("Wind: "));
+        day_invalid_count++;
+    if(!strcmp(item_value(day, "day_humidity"), "N/A"))
+        day_invalid_count++;
     if(!strcmp((char*)item_value(day, "day_wind_title"), "N/A"))
         day_invalid_count++;
     if(!strcmp((char*)item_value(day, "day_wind_speed"), "N/A"))
         day_invalid_count++;
-    sprintf(buffer + strlen(buffer), "%s\n%.2f %s",
-            (char*)hash_table_find(item_value(day, "day_wind_title"), FALSE),
-            convert_wind_units(app->config->wind_units, atof(item_value(day, "day_wind_speed"))),
-            (char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units], FALSE));
-    day_text = gtk_label_new(buffer);
-    set_font(day_label, NULL, font_size);
-    set_font(day_text, NULL, font_size-1);
-    gtk_box_pack_start(GTK_BOX(day_text_vbox),
-                       day_text, TRUE, TRUE, 0);
+
+    if(day_invalid_count < 5){
+        /* day data */
+        day_vbox = gtk_vbox_new(FALSE, 0);
+        /* hbox for day label and temperature */
+        day_label_temperature_hbox = gtk_hbox_new(FALSE, 0);
+        gtk_box_pack_start(GTK_BOX(day_vbox),
+                day_label_temperature_hbox,
+                TRUE, TRUE, 0);
+        /* prepare day label */
+        day_label = gtk_label_new(_("Day:"));
+        gtk_box_pack_start(GTK_BOX(day_label_temperature_hbox),
+                day_label, FALSE, TRUE, 0);
+        /* day temperature */
+        memset(buffer, 0, sizeof(buffer));
+        if(hi_temp == INT_MAX)
+            strncat(buffer, (char*)hash_table_find("N/A", FALSE),
+              ( (strlen((char*)hash_table_find("N/A", FALSE)) > sizeof(buffer)) ?
+              (sizeof(buffer) - 1) :
+              (strlen((char*)hash_table_find("N/A", FALSE))) ) );
+        else
+            snprintf(buffer, sizeof(hi_temp) + 
+              ( (strlen(("\302\260%c")) > sizeof(buffer)) ?
+              (sizeof(buffer) - 1) : (strlen("\302\260%c")) ),
+                "%d\302\260%c", hi_temp, symbol);
+        gtk_box_pack_start(GTK_BOX(day_label_temperature_hbox),
+              gtk_label_new(buffer), FALSE, TRUE, 40);
+        /* hbox for icon and text */
+        day_icon_text_hbox = gtk_hbox_new(FALSE, 0);
+        gtk_box_pack_start(GTK_BOX(day_vbox),
+                            day_icon_text_hbox, TRUE, TRUE, 0);
+        /* day icon */
+        memset(buffer, 0, sizeof(buffer));
+        sprintf(buffer, "%s%s.png", app->config->icons_set_base, item_value(day, "day_icon"));
+        icon = gdk_pixbuf_new_from_file_at_size(buffer,
+                            BIG_ICON_SIZE,
+                            BIG_ICON_SIZE, NULL);
+        day_icon = create_icon_widget(icon, buffer, BIG_ICON_SIZE, &app->clutter_objects_in_popup_form);
+        gtk_box_pack_start(GTK_BOX(day_icon_text_hbox),
+                            day_icon, TRUE, TRUE, 5);
+        /* prepare day text */
+        gtk_box_pack_start(GTK_BOX(day_icon_text_hbox),
+                day_text_vbox = gtk_vbox_new(FALSE, 0),
+                TRUE, TRUE, 0);
+        memset(buffer, 0, sizeof(buffer));
+        strcat(buffer, (char*)hash_table_find(item_value(day, "day_title"), FALSE));
+        strcat(buffer, _("\nPrecipitation: "));
+        snprintf(buffer + strlen(buffer), sizeof(buffer) - 1, "%s%%",
+                (char*)hash_table_find(item_value(day, "day_ppcp"), FALSE));
+        strcat(buffer, _("\nHumidity: "));
+        if(strcmp(item_value(day, "day_humidity"), "N/A"))
+            sprintf(buffer + strlen(buffer), "%s%%\n",
+            item_value(day, "day_humidity"));
+        else{
+            sprintf(buffer + strlen(buffer), "%s\n",
+                    (char*)hash_table_find("N/A", FALSE));
+        }
+        strcat(buffer, _("Wind: "));
+        sprintf(buffer + strlen(buffer), "%s\n%.2f %s",
+                (char*)hash_table_find(item_value(day, "day_wind_title"), FALSE),
+                convert_wind_units(app->config->wind_units, atof(item_value(day, "day_wind_speed"))),
+                (char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units], FALSE));
+        day_text = gtk_label_new(buffer);
+        set_font(day_label, NULL, font_size);
+        set_font(day_text, NULL, font_size-1);
+        gtk_box_pack_start(GTK_BOX(day_text_vbox),
+                        day_text, TRUE, TRUE, 0);
+        gtk_box_pack_start(GTK_BOX(day_night_hbox),
+                        day_vbox,
+                        TRUE, FALSE, 5);
+    }
     /* night data */
     night_vbox = gtk_vbox_new(FALSE, 0);
     /* hbox for night label and temperature */
@@ -909,15 +918,15 @@ GtkWidget* create_day_tab(GSList *current, GSList *day, gchar **day_name){
     strcat(buffer, (char*)hash_table_find(item_value(day, "night_title"), FALSE));
     strcat(buffer, _("\nPrecipitation: "));
     snprintf(buffer + strlen(buffer), sizeof(buffer) - 1, "%s%%",
-		(char*)hash_table_find(item_value(day, "night_ppcp"), FALSE));
+        (char*)hash_table_find(item_value(day, "night_ppcp"), FALSE));
     strcat(buffer, _("\nHumidity: "));
     if(strcmp(item_value(day, "night_humidity"), "N/A"))
-	sprintf(buffer + strlen(buffer), "%s%%\n",
-		item_value(day, "night_humidity"));
+        sprintf(buffer + strlen(buffer), "%s%%\n",
+                item_value(day, "night_humidity"));
     else{
-	sprintf(buffer + strlen(buffer), "%s\n",
-			(char*)hash_table_find("N/A", FALSE));
-	night_invalid_count++;
+        sprintf(buffer + strlen(buffer), "%s\n",
+                (char*)hash_table_find("N/A", FALSE));
+        night_invalid_count++;
     }
     strcat(buffer, _("Wind: "));
     if(!strcmp((char*)item_value(day, "night_wind_title"), "N/A"))
@@ -925,42 +934,35 @@ GtkWidget* create_day_tab(GSList *current, GSList *day, gchar **day_name){
     if(!strcmp((char*)item_value(day, "night_wind_speed"), "N/A"))
         night_invalid_count++;
     sprintf(buffer + strlen(buffer), "%s\n%.2f %s",
-	    (char*)hash_table_find(item_value(day, "night_wind_title"), FALSE),
-	    convert_wind_units(app->config->wind_units, atof(item_value(day, "night_wind_speed"))),
-	    (char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units], FALSE));
+        (char*)hash_table_find(item_value(day, "night_wind_title"), FALSE),
+        convert_wind_units(app->config->wind_units, atof(item_value(day, "night_wind_speed"))),
+        (char*)hash_table_find((gpointer)wind_units_str[app->config->wind_units], FALSE));
     night_text = gtk_label_new(buffer);
     set_font(night_label, NULL, font_size);
     set_font(night_text, NULL, font_size-1);
     gtk_box_pack_start(GTK_BOX(night_text_vbox),
-			night_text, TRUE, TRUE, 0);
+                      night_text, TRUE, TRUE, 0);
     /* add day and night items to main widget */
-    /* check for N/A fields in day */
-    if(day_invalid_count < 5)
-	    gtk_box_pack_start(GTK_BOX(day_night_hbox),
-			    day_vbox,
-			    TRUE, FALSE, 5);
-    else
-	    gtk_widget_destroy(day_vbox);
     /* check for N/A fields in night */
     if(night_invalid_count < 5)
-	    gtk_box_pack_start(GTK_BOX(day_night_hbox),
-			    night_vbox,
-			    TRUE, FALSE, 5);
+        gtk_box_pack_start(GTK_BOX(day_night_hbox),
+                      night_vbox,
+                      TRUE, FALSE, 5);
     else
-	    gtk_widget_destroy(night_vbox);
+        gtk_widget_destroy(night_vbox);
     /* day name with date */
     gtk_box_pack_start(GTK_BOX(main_widget), title, FALSE, FALSE, 5);
     /* day and/or night data */
     gtk_box_pack_start(GTK_BOX(main_widget), day_night_hbox, FALSE, FALSE, 5);
     /* sunrise and sunset time */
     gtk_box_pack_start(GTK_BOX(main_widget),
-			create_sun_time_widget(day),
-			TRUE, FALSE, 0);
+                      create_sun_time_widget(day),
+                      TRUE, FALSE, 0);
     /* last update time */
     if(current)
-	gtk_box_pack_start(GTK_BOX(main_widget),
-			    create_time_updates_widget(current, FALSE),
-			    TRUE, FALSE, 5);
+        gtk_box_pack_start(GTK_BOX(main_widget),
+                           create_time_updates_widget(current, FALSE),
+                          TRUE, FALSE, 5);
     gtk_widget_show_all(main_widget);
 
 #if defined CLUTTER
